==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Obre amb...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Preferit</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Personalitzat</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Ubicació del binari</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Fes que aquesta sigui l&apos;aplicació predeterminada </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Enllaç de correu electrònic)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(URL d&apos;Internet - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimèdia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Educació</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Ciència</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitats</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation>[per defecte] </translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>Troba el binari de l&apos;aplicació</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>File Error</source>
        <translation>Error del fitxer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>Volum de l&apos;àudio: %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>Brillantor de la pantalla: %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>Fitxer o URL no vàlids: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation>L&apos;entrada de l&apos;aplicació no és vàlida: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>La drecera de l&apos;aplicació no té la informació de llançament (drecera malformada): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>La drecera de l&apos;URL no té l&apos;URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>La drecera del directori no té el camí cap al directori: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Tipus de drecera desconegut: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Binary Missing</source>
        <translation>Falta un binari</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>No s&apos;ha pogut trobar &quot;%1&quot;. Si us plau, assegureu-vos que estigui instal·lat.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>Application Error</source>
        <translation>Error de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>L&apos;aplicació següent ha tingut un error i s&apos;ha hagut de tancar:</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Obre amb...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Preferit</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Personalitzat</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Ubicació del binari</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Fes que aquesta sigui l&apos;aplicació predeterminada </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Enllaç de correu electrònic)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(URL d&apos;Internet - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimèdia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Educació</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Ciència</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitats</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation>[per defecte] </translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>Troba el binari de l&apos;aplicació</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>File Error</source>
        <translation>Error del fitxer</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>Volum de l&apos;àudio: %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>Brillantor de la pantalla: %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>Fitxer o URL no vàlids: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation>L&apos;entrada de l&apos;aplicació no és vàlida: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>La drecera de l&apos;aplicació no té la informació de llançament (drecera malformada): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>La drecera de l&apos;URL no té l&apos;URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>La drecera del directori no té el camí cap al directori: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Tipus de drecera desconegut: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>No s&apos;ha pogut trobar &quot;%1&quot;. Si us plau, assegureu-vos que estigui instal·lat.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>Application Error</source>
        <translation>Error de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>L&apos;aplicació següent ha tingut un error i s&apos;ha hagut de tancar:</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished">Multimèdia</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished">Desenvolupament</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished">Educació</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished">Gràfics</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished">Xarxa</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished">Oficina</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished">Ciència</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">Configuració</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished">Sistema</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
